Changelog
=========

.. You should *NOT* be adding new change log entries to this file.
   You should create a file in the news directory instead.

.. towncrier release notes start

1.0 (2025-04-11)
----------------

No significant changes.


1.0a10 (2024-09-30)
-------------------

Bug fixes:


- Extract commits ignoring merged [Bermúdez Horcajada, Rafael] (#1)


1.0a9 (2024-09-24)
------------------

Bug fixes:


- Fix duplicate entries


1.0a8 (2024-09-20)
------------------

New features:


- Git add after all files are updated.


1.0a7 (2024-09-20)
------------------

Bug fixes:


- Ensure the newsfile is added to the git index to avoid pre-commit hooks to fail


1.0a6 (2024-09-20)
------------------

Bug fixes:


- Don't assign encoding to file


1.0a5 (2024-09-20)
------------------

New features:


- Execute at hook zest.releaser.prereleaser.before


1.0a4 (2024-09-20)
------------------

Bug fixes:


- Fix regex pattern to extract prefix properly [Rafael Bermúdez Horcajada <rber474@gmail.com>]


1.0a3 (2024-09-19)
------------------

Bug fixes:


- Fix release workfloww [Rafael Bermúdez Horcajada <rber474@gmail.com>]


1.0a2 (2024-09-19)
------------------

New features:


- Switch to OpenID Connect [Rafael Bermúdez Horcajada <rber474@gmail.com>]


1.0a1 (unreleased)
------------------

- Initial release.
  [rber474]
